Stan Math Library: stan/math/rev/scal/fun/exp2.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

exp2.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_EXP2_HPP
2 #define STAN_MATH_REV_SCAL_FUN_EXP2_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <stan/math/prim/scal/fun/constants.hpp>
6 #include <cmath>
7 #include <valarray>
8
9 namespace stan {
10 namespace math {
11
12 namespace {
13 class exp2_vari : public op_v_vari {
14 public:
15 explicit exp2_vari(vari* avi) :
16 op_v_vari(std::pow(2.0, avi->val_), avi) {
17 }
18 void chain() {
19 avi_->adj_ += adj_ * val_ * stan::math::LOG_2;
20 }
21 };
22 }
23
52 inline var exp2(const var& a) {
53 return var(new exp2_vari(a.vi_));
54 }
55
56 }
57 }
58 #endif
stan::math::LOG_2
const double LOG_2
The natural logarithm of 2, .
Definition: constants.hpp:33
core.hpp
stan
Definition: log_sum_exp.hpp:8
std
Definition: std_numeric_limits.hpp:7
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43
stan::math::exp2
fvar< T > exp2(const fvar< T > &x)
Definition: exp2.hpp:14
constants.hpp
stan::math::pow
fvar< T > pow(const fvar< T > &x1, const fvar< T > &x2)
Definition: pow.hpp:18

[ Stan Home Page ] © 2011–2016, Stan Development Team.